@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-__version__ = '0.3'
+__version__ = '0.4'
 # release is the one with 'dev' on the end
-__release__ = '0.3'
+__release__ = '0.4.0'
 
